==> alg-alg-1.50.8-sources.jar: cn/com/duiba/nezha/alg/alg/coldstartandexplore/SimpleTest.java <==
package cn.com.duiba.nezha.alg.alg.coldstartandexplore;

import cn.com.duiba.nezha.alg.common.util.MathUtil;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class SimpleTest {

    /**
     * 调权因子加权函数
     */
    public static List<Double> functionOfRectifyFac(int size) {
        List<Double> res = new ArrayList<>();
        double weight = 1.0;
        Map<String, Double> KBMap1 = calculateKAndB(0, (int) (0.1 * size), 1.3, 1.1);
        Map<String, Double> KBMap2 = calculateKAndB((int) (0.1 * size), (int) (0.2 * size), 1.1, 1.0);
        double k1 = KBMap1.get("K");
        double k2 = KBMap2.get("K");
        double b1 = KBMap1.get("B");
        double b2 = KBMap1.get("B");

        for (int i=0; i<size; i++) {
            if (i <= (int) (0.1 * size)) {
                weight = k1 * i + b1;
            }else if((int) (0.1 * size) < i && i <= (int) (0.2 * size)) {
                weight = k2 * i + b2;
            }else { weight = 1.0; }

            weight = Math.round(weight * 1e6) / 1e6;
            res.add(Math.max(weight, 1.0));
        }

        return res;
    }


    /**
     * 调权因子加权函数斜率及偏置的计算
     */
    private static Map<String, Double> calculateKAndB(int x0, int x1, double y0, double y1) {
        Map<String, Double> res = new HashMap<>();

        double k = MathUtil.division(y1 - y0, x1 - x0, 6);
        double b = y0 - k * x0;
        res.put("K", k);
        res.put("B", b);

        return res;
    }

    public static void main(String[] args) {
//        List<Double> res = new ArrayList<>();
//        int size = 40;
//        res = functionOfRectifyFac(size);
//        System.out.println(res);

        Double a = 0.0;
        Double b = 0.0;

        System.out.println( MathUtil.division(a, b, 6));

        double d = MathUtil.division(a, b, 6);

    }
}

==> alg-alg-1.51.8-sources.jar: cn/com/duiba/nezha/alg/alg/coldstartandexplore/SimpleTest.java <==
package cn.com.duiba.nezha.alg.alg.coldstartandexplore;

import cn.com.duiba.nezha.alg.common.util.MathUtil;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class SimpleTest {

    /**
     * 调权因子加权函数
     */
    public static List<Double> functionOfRectifyFac(int size) {
        List<Double> res = new ArrayList<>();
        double weight = 1.0;
        Map<String, Double> KBMap1 = calculateKAndB(0, (int) (0.1 * size), 1.3, 1.1);
        Map<String, Double> KBMap2 = calculateKAndB((int) (0.1 * size), (int) (0.2 * size), 1.1, 1.0);
        double k1 = KBMap1.get("K");
        double k2 = KBMap2.get("K");
        double b1 = KBMap1.get("B");
        double b2 = KBMap1.get("B");

        for (int i=0; i<size; i++) {
            if (i <= (int) (0.1 * size)) {
                weight = k1 * i + b1;
            }else if((int) (0.1 * size) < i && i <= (int) (0.2 * size)) {
                weight = k2 * i + b2;
            }else { weight = 1.0; }

            weight = Math.round(weight * 1e6) / 1e6;
            res.add(Math.max(weight, 1.0));
        }

        return res;
    }


    /**
     * 调权因子加权函数斜率及偏置的计算
     */
    private static Map<String, Double> calculateKAndB(int x0, int x1, double y0, double y1) {
        Map<String, Double> res = new HashMap<>();

        double k = MathUtil.division(y1 - y0, x1 - x0, 6);
        double b = y0 - k * x0;
        res.put("K", k);
        res.put("B", b);

        return res;
    }

    public static void main(String[] args) {
//        List<Double> res = new ArrayList<>();
//        int size = 40;
//        res = functionOfRectifyFac(size);
//        System.out.println(res);

//        Double a = 0.0;
//        Double b = 0.0;
//
//        System.out.println( MathUtil.division(a, b, 6));
//
//        double d = MathUtil.division(a, b, 6);

        System.out.println((int) 3.6);

    }
}
